==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/examples.js <==
var examples =
[
    [ "Polygon_mesh_processing/extrude.cpp", "Polygon_mesh_processing_2extrude_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/polyhedral_envelope.cpp", "Polygon_mesh_processing_2polyhedral_envelope_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/polyhedral_envelope_of_triangle_soup.cpp", "Polygon_mesh_processing_2polyhedral_envelope_of_triangle_soup_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/polyhedral_envelope_mesh_containment.cpp", "Polygon_mesh_processing_2polyhedral_envelope_mesh_containment_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/self_intersections_example.cpp", "Polygon_mesh_processing_2self_intersections_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hole_filling_example.cpp", "Polygon_mesh_processing_2hole_filling_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hole_filling_example_SM.cpp", "Polygon_mesh_processing_2hole_filling_example_SM_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hole_filling_visitor_example.cpp", "Polygon_mesh_processing_2hole_filling_visitor_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/stitch_borders_example.cpp", "Polygon_mesh_processing_2stitch_borders_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/compute_normals_example.cpp", "Polygon_mesh_processing_2compute_normals_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/point_inside_example.cpp", "Polygon_mesh_processing_2point_inside_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/triangulate_faces_example.cpp", "Polygon_mesh_processing_2triangulate_faces_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/connected_components_example.cpp", "Polygon_mesh_processing_2connected_components_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/face_filtered_graph_example.cpp", "Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/orient_polygon_soup_example.cpp", "Polygon_mesh_processing_2orient_polygon_soup_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/triangulate_polyline_example.cpp", "Polygon_mesh_processing_2triangulate_polyline_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/refine_fair_example.cpp", "Polygon_mesh_processing_2refine_fair_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/mesh_slicer_example.cpp", "Polygon_mesh_processing_2mesh_slicer_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_example.cpp", "Polygon_mesh_processing_2isotropic_remeshing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/interpolated_corrected_curvatures_SM.cpp", "Polygon_mesh_processing_2interpolated_corrected_curvatures_SM_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/interpolated_corrected_curvatures_PH.cpp", "Polygon_mesh_processing_2interpolated_corrected_curvatures_PH_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/interpolated_corrected_curvatures_vertex.cpp", "Polygon_mesh_processing_2interpolated_corrected_curvatures_vertex_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/delaunay_remeshing_example.cpp", "Polygon_mesh_processing_2delaunay_remeshing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/compute_normals_example_Polyhedron.cpp", "Polygon_mesh_processing_2compute_normals_example_Polyhedron_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hausdorff_distance_remeshing_example.cpp", "Polygon_mesh_processing_2hausdorff_distance_remeshing_example_8cpp-example.html", null ],
    [ "Poisson_surface_reconstruction_3/poisson_reconstruction_example.cpp", "Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_difference_remeshed.cpp", "Polygon_mesh_processing_2corefinement_difference_remeshed_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_mesh_union.cpp", "Polygon_mesh_processing_2corefinement_mesh_union_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_mesh_union_progress.cpp", "Polygon_mesh_processing_2corefinement_mesh_union_progress_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_OM_union.cpp", "Polygon_mesh_processing_2corefinement_OM_union_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_mesh_union_and_intersection.cpp", "Polygon_mesh_processing_2corefinement_mesh_union_and_intersection_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_consecutive_bool_op.cpp", "Polygon_mesh_processing_2corefinement_consecutive_bool_op_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/detect_features_example.cpp", "Polygon_mesh_processing_2detect_features_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/volume_connected_components.cpp", "Polygon_mesh_processing_2volume_connected_components_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/manifoldness_repair_example.cpp", "Polygon_mesh_processing_2manifoldness_repair_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/repair_polygon_soup_example.cpp", "Polygon_mesh_processing_2repair_polygon_soup_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/mesh_smoothing_example.cpp", "Polygon_mesh_processing_2mesh_smoothing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/shape_smoothing_example.cpp", "Polygon_mesh_processing_2shape_smoothing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/tangential_relaxation_example.cpp", "Polygon_mesh_processing_2tangential_relaxation_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/locate_example.cpp", "Polygon_mesh_processing_2locate_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/orientation_pipeline_example.cpp", "Polygon_mesh_processing_2orientation_pipeline_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/triangulate_faces_split_visitor_example.cpp", "Polygon_mesh_processing_2triangulate_faces_split_visitor_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hausdorff_bounded_error_distance_example.cpp", "Polygon_mesh_processing_2hausdorff_bounded_error_distance_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/cc_compatible_orientations.cpp", "Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/remesh_planar_patches.cpp", "Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/remesh_almost_planar_patches.cpp", "Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/sample_example.cpp", "Polygon_mesh_processing_2sample_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/soup_autorefinement.cpp", "Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_with_allow_move.cpp", "Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html", null ]
];

==> CGAL-6.0.3-doc_html.tar.xz: doc_html/Polygon_mesh_processing/examples.js <==
var examples =
[
    [ "Polygon_mesh_processing/extrude.cpp", "Polygon_mesh_processing_2extrude_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/polyhedral_envelope.cpp", "Polygon_mesh_processing_2polyhedral_envelope_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/polyhedral_envelope_of_triangle_soup.cpp", "Polygon_mesh_processing_2polyhedral_envelope_of_triangle_soup_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/polyhedral_envelope_mesh_containment.cpp", "Polygon_mesh_processing_2polyhedral_envelope_mesh_containment_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/self_intersections_example.cpp", "Polygon_mesh_processing_2self_intersections_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hole_filling_example.cpp", "Polygon_mesh_processing_2hole_filling_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hole_filling_example_SM.cpp", "Polygon_mesh_processing_2hole_filling_example_SM_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hole_filling_visitor_example.cpp", "Polygon_mesh_processing_2hole_filling_visitor_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/stitch_borders_example.cpp", "Polygon_mesh_processing_2stitch_borders_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/compute_normals_example.cpp", "Polygon_mesh_processing_2compute_normals_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/point_inside_example.cpp", "Polygon_mesh_processing_2point_inside_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/triangulate_faces_example.cpp", "Polygon_mesh_processing_2triangulate_faces_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/connected_components_example.cpp", "Polygon_mesh_processing_2connected_components_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/face_filtered_graph_example.cpp", "Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/orient_polygon_soup_example.cpp", "Polygon_mesh_processing_2orient_polygon_soup_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/triangulate_polyline_example.cpp", "Polygon_mesh_processing_2triangulate_polyline_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/refine_fair_example.cpp", "Polygon_mesh_processing_2refine_fair_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/mesh_slicer_example.cpp", "Polygon_mesh_processing_2mesh_slicer_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_example.cpp", "Polygon_mesh_processing_2isotropic_remeshing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_of_patch_example.cpp", "Polygon_mesh_processing_2isotropic_remeshing_of_patch_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_with_allow_move.cpp", "Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_with_custom_sizing_example.cpp", "Polygon_mesh_processing_2isotropic_remeshing_with_custom_sizing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/isotropic_remeshing_with_sizing_example.cpp", "Polygon_mesh_processing_2isotropic_remeshing_with_sizing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/interpolated_corrected_curvatures_SM.cpp", "Polygon_mesh_processing_2interpolated_corrected_curvatures_SM_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/interpolated_corrected_curvatures_PH.cpp", "Polygon_mesh_processing_2interpolated_corrected_curvatures_PH_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/interpolated_corrected_curvatures_vertex.cpp", "Polygon_mesh_processing_2interpolated_corrected_curvatures_vertex_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/delaunay_remeshing_example.cpp", "Polygon_mesh_processing_2delaunay_remeshing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/compute_normals_example_Polyhedron.cpp", "Polygon_mesh_processing_2compute_normals_example_Polyhedron_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hausdorff_distance_remeshing_example.cpp", "Polygon_mesh_processing_2hausdorff_distance_remeshing_example_8cpp-example.html", null ],
    [ "Poisson_surface_reconstruction_3/poisson_reconstruction_example.cpp", "Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_difference_remeshed.cpp", "Polygon_mesh_processing_2corefinement_difference_remeshed_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_mesh_union.cpp", "Polygon_mesh_processing_2corefinement_mesh_union_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_mesh_union_progress.cpp", "Polygon_mesh_processing_2corefinement_mesh_union_progress_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_OM_union.cpp", "Polygon_mesh_processing_2corefinement_OM_union_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_mesh_union_and_intersection.cpp", "Polygon_mesh_processing_2corefinement_mesh_union_and_intersection_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/corefinement_consecutive_bool_op.cpp", "Polygon_mesh_processing_2corefinement_consecutive_bool_op_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/detect_features_example.cpp", "Polygon_mesh_processing_2detect_features_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/volume_connected_components.cpp", "Polygon_mesh_processing_2volume_connected_components_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/manifoldness_repair_example.cpp", "Polygon_mesh_processing_2manifoldness_repair_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/repair_polygon_soup_example.cpp", "Polygon_mesh_processing_2repair_polygon_soup_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/mesh_smoothing_example.cpp", "Polygon_mesh_processing_2mesh_smoothing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/shape_smoothing_example.cpp", "Polygon_mesh_processing_2shape_smoothing_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/tangential_relaxation_example.cpp", "Polygon_mesh_processing_2tangential_relaxation_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/locate_example.cpp", "Polygon_mesh_processing_2locate_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/orientation_pipeline_example.cpp", "Polygon_mesh_processing_2orientation_pipeline_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/triangulate_faces_split_visitor_example.cpp", "Polygon_mesh_processing_2triangulate_faces_split_visitor_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/hausdorff_bounded_error_distance_example.cpp", "Polygon_mesh_processing_2hausdorff_bounded_error_distance_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/cc_compatible_orientations.cpp", "Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/remesh_planar_patches.cpp", "Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/remesh_almost_planar_patches.cpp", "Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/sample_example.cpp", "Polygon_mesh_processing_2sample_example_8cpp-example.html", null ],
    [ "Polygon_mesh_processing/soup_autorefinement.cpp", "Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html", null ]
];
